@@ -148,6 +148,13 @@ on_window1_realize                     (GtkWidget       *widget,
   if (is_dock) {
 	  gok_main_set_wm_dock (TRUE);
   }
+  else {
+	  if (widget->window) {
+		  gdk_window_set_decorations (widget->window, GDK_DECOR_ALL | 
+					      GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
+		  gdk_window_set_functions (widget->window, GDK_FUNC_MOVE | GDK_FUNC_RESIZE);
+	  }
+  }
 
   gtk_window_stick (GTK_WINDOW (widget));
 
@@ -163,6 +170,12 @@ on_window1_realize                     (GtkWidget       *widget,
   gdk_window_add_filter (widget->window,
 			 gok_discard_focus_filter,
 			 NULL);
+
+  if (!gok_main_check_sticky_keys (widget)) {
+	  gok_main_close ();
+	  gtk_exit (0);
+  }
+
 }
 
 
