@@ -51,21 +51,21 @@ static gboolean m_bSettingsChanged;
  If you add a new setting then add it here and update write, read and initialize
  All these settings have accessor functions.
 */
-gint m_GokKeyWidth;
-gint m_GokKeyHeight;
-gint m_GokKeySpacing;
-gint m_GokKeyboardX;
-gint m_GokKeyboardY;
-gboolean m_bKeysizePriority;
-gboolean m_bWordCompleteOn;
-gboolean m_bCommandPredictOn;
-gint m_NumberPredictions;
-char NameAccessMethod [MAX_ACCESS_METHOD_NAME];
-gboolean m_bUseGtkPlusTheme;
-gboolean m_bDriveCorePointer = FALSE;
-gboolean m_bExpandWindow;
-gboolean m_bUseXkbKbd;
-gboolean m_eDockType;
+static gint m_GokKeyWidth;
+static gint m_GokKeyHeight;
+static gint m_GokKeySpacing;
+static gint m_GokKeyboardX;
+static gint m_GokKeyboardY;
+static gboolean m_bKeysizePriority;
+static gboolean m_bWordCompleteOn;
+static gboolean m_bCommandPredictOn;
+static gint m_NumberPredictions;
+static char NameAccessMethod [MAX_ACCESS_METHOD_NAME];
+static gboolean m_bUseGtkPlusTheme;
+static gboolean m_bDriveCorePointer = FALSE;
+static gboolean m_bExpandWindow;
+static gboolean m_bUseXkbKbd;
+static GokDockType m_eDockType;
 
 /* This GConfClient will be shared by all gconf_client
  * calls in this file.
@@ -708,8 +708,9 @@ GokDockType gok_data_get_dock_type ()
  */
 void gok_data_set_dock_type (GokDockType val)
 {
-	m_eDockType = val;
 	gchar *typestring;
+
+	m_eDockType = val;
 	switch (val) {
 	case GOK_DOCK_TOP:
 	  typestring = "top";
