@@ -24,6 +24,7 @@
 #endif
 
 #include <string.h>
+#include <gnome.h>
 #include "gok-key.h"
 #include "gok-keyboard.h"
 #include "gok-mousecontrol.h"
@@ -1322,22 +1323,26 @@ gok_key_create_image_widget (GokKey* pKey)
 		case IMAGE_TYPE_FIXED:
 		default:
 			if ((pKey->pImage->w == -1) && (pKey->pImage->h == -1)) {
-				image = gtk_image_new_from_file (
-					gok_key_get_image_filename (pKey));
+				file = gok_key_get_image_filename (pKey);
+				image = gtk_image_new_from_file (file);
+				g_free (file);
 			}
 			else {
 				GdkPixbuf *scaled = NULL, *pixbuf;
-				pixbuf = gdk_pixbuf_new_from_file (
-					gok_key_get_image_filename (pKey), NULL);
-				if (pixbuf)
+				file = gok_key_get_image_filename (pKey);
+				pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+				g_free (file);
+				if (pixbuf) {
 					scaled = gdk_pixbuf_scale_simple (
 						pixbuf, pKey->pImage->w,
 						pKey->pImage->h, 
 						GDK_INTERP_BILINEAR);
-				g_object_unref (pixbuf);
-				if (scaled)
+					g_object_unref (pixbuf);
+				}
+				if (scaled) {
 					image = gtk_image_new_from_pixbuf (scaled);
-				g_object_unref (scaled);
+					g_object_unref (scaled);
+				}
 			}
 			break;
 		}
@@ -2157,10 +2162,13 @@ gok_keyimage_delete (GokKeyImage* pKeyImage)
 gchar*
 gok_key_get_image_filename (GokKey* pKey)
 {
+	gchar *filename = NULL;
 	g_assert (pKey != NULL);
-	
-	/* this needs to get the filename for the normal modifier key */
-	return pKey->pImage->Filename;
+
+	filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
+					      pKey->pImage->Filename,
+					      FALSE, NULL);
+	return filename;
 }
 
 /**
