@@ -27,14 +27,17 @@
 #include <gnome.h>
 #include <cspi/spi.h>
 
-#define OUTPUT_KEYSYM 0
-#define OUTPUT_KEYCODE 1
-#define OUTPUT_EXEC 2
-
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
+typedef enum {
+	OUTPUT_KEYSYM,
+	OUTPUT_KEYCODE,
+	OUTPUT_KEYSTRING,
+	OUTPUT_EXEC
+} GokOutputType;
+
 /* an output */
 typedef struct GokOutput{
 	gint Type;
