@@ -156,6 +156,103 @@ static gchar ArrayCallNames[MAX_CALL_NAMES][24] ={
 "GetRate"
 };
 
+static xmlChar *gok_lang = NULL;
+
+/**
+ * gok_scanner_get_lang:
+ * returns: a string specifying the target language, conforming to IETF RFC 1766.
+ **/
+xmlChar *
+gok_scanner_get_lang (void)
+{
+	if (!gok_lang) {
+		gchar *lang = setlocale (LC_MESSAGES, NULL);
+		gchar **strings = NULL;
+		/* strip suffixes, etc. */
+		if (lang) 
+			strings = g_strsplit (lang, ".", 2);
+		g_free (lang);
+		if (strings && strings[1]) 
+			g_free (strings[1]);
+		if (strings && strings[0]) {
+			lang = strings[0];
+			strings = g_strsplit (lang, "@", 2);
+			if (strings[1]) 
+				g_free (strings[1]);
+			gok_lang = strings[0];
+		}
+		else
+			gok_lang = "";
+	}
+	fprintf (stderr, "gok_lang=%s\n", gok_lang);
+	return gok_lang;
+}
+
+/**
+ * gok_scanner_find_node:
+ *
+ * @pNode: Pointer to the XML node that may contain the node you're looking for.
+ * @NameNode: Name of the node you're looking for.
+ * @target_lang: String indicating the target language, or NULL if we don't care.
+ * @node_lang: Pointer to a string which, if non-null, is filled with the xml:lang
+ * tag of the node returned.
+ *
+ * returns: A pointer to the first node that has the given name and which provides
+ *          the "best available match" to a target locale, NULL 
+ *          if no node with the specified name can be found.
+ *
+ * Recursive method which find the first node matching the given name and providing the "best"
+ * match to the specified locale.  Locale matching prefers a perfect match, otherwise matches the
+ * locale ignoring suffixes, and falls back to "C".  If @target_lang lacks a suffix, 
+ * returns the first node matching the target language, ignoring variants/suffixes.
+ **/
+xmlNode*
+gok_scanner_find_node (xmlNode *pNode, const xmlChar* name, const xmlChar* target_lang, 
+		       xmlChar **node_lang)
+{
+	xmlNode *retval = NULL;
+	int      target_lang_len = strlen (target_lang);
+	gboolean lang_is_matched = FALSE;	
+
+	/* loop through the document looking for the name string */
+	while (pNode != NULL)
+	{
+		/* does this node's name match ? */
+		if (xmlStrcmp (pNode->name, name) == 0)
+		{
+			xmlChar *lang = NULL;
+			gboolean is_lang_match = FALSE;
+			gboolean is_perfect_match = FALSE;
+			/* If xml:lang matches our locale, return, else keep looking... */
+			lang = xmlNodeGetLang (pNode);
+			if (lang) {
+				is_lang_match = !xmlStrncmp (lang, target_lang, 2);
+			}
+			if (is_lang_match || 
+			    ((!lang || !xmlStrcmp (lang, (const xmlChar *) "C")) && (!lang_is_matched))) {
+				retval = pNode;
+				if (!xmlStrncmp (lang, target_lang, target_lang_len)) { /* perfect match */
+					if (lang && node_lang) *node_lang = lang;
+					return retval;
+				}
+				else if (is_lang_match) {
+					if (node_lang) {
+						if (*node_lang) g_free (*node_lang);
+						*node_lang = lang;
+					}
+					lang_is_matched = TRUE;
+				}
+				else {
+					g_free (lang);
+				}
+			}
+		}
+		pNode = pNode->next;
+	}
+
+	return retval;
+}
+
 /*
  * gok_scanner_get_slop:
  * Return the number of pixels beyond the
@@ -846,21 +943,16 @@ gboolean gok_scanner_read_description (xmlDoc* pDoc, xmlNode* pNode, GokAccessMe
 	g_assert (pNode != NULL);
 	g_assert (pAccessMethod != NULL);
 
-	/* loop through the document looking for the description */
-	while (pNode != NULL)
-	{
-		/* is this node a description? */
-		if (xmlStrcmp (pNode->name, (const xmlChar *) "description") == 0)
-		{
-			pStringDescription = xmlNodeListGetString (pDoc, pNode->xmlChildrenNode, 1);
-			strncpy (pAccessMethod->Description, (gchar *)pStringDescription, MAX_DESCRIPTION_TEXT);
-			g_free (pStringDescription);
-			return TRUE;
-		}
-		pNode = pNode->next;
+	if (pNode = gok_scanner_find_node (pNode, (const xmlChar *) "description", gok_scanner_get_lang (),
+					   NULL)) {
+		pStringDescription = xmlNodeListGetString (pDoc, pNode->xmlChildrenNode, 1);
+		strncpy (pAccessMethod->Description, (gchar *)pStringDescription, MAX_DESCRIPTION_TEXT);
+		g_free (pStringDescription);
+		return TRUE;
+	}
+	else {
+		return FALSE;
 	}
-
-	return FALSE;
 }
 
 /**
