@@ -185,11 +185,14 @@ int gok_wordcomplete_predict (const gunichar letter)
 	        gchar *tmp, utf8char[7]; /* min 6, plus NULL */
 
 		/* 
-		 * Is this whitespace, empty, or nonprintable? Also catches NULL/0 
+		 * Is this whitespace, empty, punctuation, or nonprintable? Also catches NULL/0 
 		 * we make exception for U+00a0 (nonbreak space) so 'words' containing 
-		 * space can be handled.
+		 * space can be handled. 
 		 */
-		if (!g_unichar_validate (letter) || !g_unichar_isgraph (letter) && (letter != 0x00a0))
+		if (!g_unichar_validate (letter) ||  /* if invalid, */
+		    ((g_unichar_ispunct (letter) || !g_unichar_isgraph (letter)) /* or punct/non-graphical, */
+		     && (letter != 0x00a0)) || /* but not nbspace */
+		    (letter == 0x2f)) /* or if destructive backspace */
 		{
 			/* reset the part word */
 			gok_wordcomplete_end_word ();		
@@ -316,8 +319,19 @@ void gok_wordcomplete_clear_keys ()
 **/
 gboolean gok_wordcomplete_add_new_word (const gchar* pWord)
 {
-	/* TODO : implement */
-	return TRUE;
+        return WordCompleteAddNewWord (pWord);
+}
+
+/**
+* gok_wordcomplete_increment_word_frequency
+* 
+* Increments the frequency of a word in the dictionary.
+*
+* returns: TRUE if the word's frequency was incremented, FALSE if not.
+**/
+gboolean gok_wordcomplete_increment_word_frequency (const gchar* pWord)
+{
+	return WordCompleteIncrementFrequency (pWord);
 }
 
 /**
