@@ -63,6 +63,7 @@
 #include <signal.h>
 #include "gok-bounds.h"
 
+#define USE_GCONF 1
 
 #define APP_STATIC_BUFF_SZ 30
 #define MAX_DELETABLE_KEYBOARDS 50
@@ -77,6 +78,8 @@
 
 #define GOKMAINKEYBOARDNAME "main"
 
+#define KEYBOARD_ACCESSIBILITY_STICKY_KEYS_KEY "/desktop/gnome/accessibility/keyboard/stickykeys_enable"
+
 /* pointer to the first keyboard in the list of keyboards */
 static GokKeyboard* m_pKeyboardFirst = NULL;
 
@@ -1965,10 +1968,17 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 		} 
 		if (!xkb || !(xkb->ctrls->enabled_ctrls & XkbStickyKeysMask)) {
 			/* Turn on sticky keys and warn user! */
+#if USE_GCONF
+			if (1) {
+				GConfClient *gconf_client = gconf_client_get_default ();
+				gok_gconf_set_bool (gconf_client, KEYBOARD_ACCESSIBILITY_STICKY_KEYS_KEY, 
+						    TRUE); /* turn on gconf key */
+#else
 			if (XkbChangeEnabledControls (display,
 						      XkbUseCoreKbd,
 						      XkbStickyKeysMask,
 						      XkbStickyKeysMask)) {
+#endif
 				xkb_ok = TRUE;
 				dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
 								 GTK_DIALOG_DESTROY_WITH_PARENT,
